import * as React from 'react'
import Box from '@mui/material/Box'
import Collapse from '@mui/material/Collapse'
import IconButton from '@mui/material/IconButton'
import Table from '@mui/material/Table'
import TableBody from '@mui/material/TableBody'
import TableCell from '@mui/material/TableCell'
import TableContainer from '@mui/material/TableContainer'
import TableHead from '@mui/material/TableHead'
import TableRow from '@mui/material/TableRow'
import Typography from '@mui/material/Typography'
import Paper from '@mui/material/Paper'
import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown'
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp'

function createData (
  name: string,
  type: string,
  dataspace: string
) {
  return {
    name,
    type,
    dataspace,
    details: [
      {
        update: '2020-01-05',
        customerId: '11091700',
        amount: 'ASS'
      },
      {
        update: '2020-01-02',
        customerId: '23987003',
        amount: 'LinkAhead'
      }
    ]
  }
}

function Row (props: { row: ReturnType<typeof createData> }) {
  const { row } = props
  const [open, setOpen] = React.useState(false)

  return (
    <React.Fragment>
      <TableRow sx={{ '& > *': { borderBottom: 'unset' } }}>
        <TableCell>
          <IconButton
            aria-label="expand row"
            size="small"
            onClick={() => { setOpen(!open) }}
          >
            {open ? <KeyboardArrowUpIcon /> : <KeyboardArrowDownIcon />}
          </IconButton>
        </TableCell>
        <TableCell component="th" scope="row">
          {row.name}
        </TableCell>
        <TableCell align="right">{row.type}</TableCell>
        <TableCell align="right">{row.dataspace}</TableCell>
      </TableRow>
      <TableRow>
        <TableCell style={{ paddingBottom: 0, paddingTop: 0 }} colSpan={6}>
          <Collapse in={open} timeout="auto" unmountOnExit>
            <Box sx={{ margin: 1 }}>
              <Typography variant="h6" gutterBottom component="div">
                Details
              </Typography>
              <Table size="small" aria-label="purchases">
                <TableHead>
                  <TableRow>
                    <TableCell>UPDATE</TableCell>
                    <TableCell>CUSTOMER-ID</TableCell>
                    <TableCell align="right">DATASPACE</TableCell>
                  </TableRow>
                </TableHead>
                <TableBody>
                  {row.details.map((detailsRow) => (
                    <TableRow key={detailsRow.update}>
                      <TableCell component="th" scope="row">
                        {detailsRow.update}
                      </TableCell>
                      <TableCell>{detailsRow.customerId}</TableCell>
                      <TableCell component="th" scope="row">
                      </TableCell>
                      <TableCell>{detailsRow.amount}</TableCell>
                      <TableCell component="th" scope="row">
                      </TableCell>
                    </TableRow>
                  ))}
                </TableBody>
              </Table>
            </Box>
          </Collapse>
        </TableCell>
      </TableRow>
    </React.Fragment>
  )
}
const rows = [
  createData('CETTS-D2-2024-07-08', '159', '6.0'),
  createData('CETTS-D2-2024-06-24', '237', '9.0'),
  createData('CETTS-XD2-2024-06-03', '262', '16.0'),
  createData('CETTS-L2a-2024-05-08', '305', '3.7'),
  createData('CETTS-XD3a-2024-03-11', '356', '16.0')
]
export default function CollapsibleTable () {
  return (
    <TableContainer component={Paper}>
      <Table aria-label="collapsible table">
        <TableHead>
          <TableRow>
            <TableCell />
            <TableCell>Name & Date</TableCell>
            <TableCell align="right">Time</TableCell>
            <TableCell align="right">Device</TableCell>
            <TableCell align="right">Status</TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {rows.map((row) => (
            <Row key={row.name} row={row} />
          ))}
        </TableBody>
      </Table>
    </TableContainer>
  )
}
